from bluer_objects.README.items import ImageItems

from bluer_ugv.README.consts import assets, assets2_bluer_swallow

items = ImageItems(
    {
        f"{assets}/bluer-ugv/bluer-light.png": "",
        "../../../diagrams/bluer_swallow/3d-design.png": "../../../diagrams/bluer_swallow/3d-design.stl",
        f"{assets2_bluer_swallow}/20250605_180136.jpg": "",
        f"{assets2_bluer_swallow}/20250608_144453.jpg": "",
        f"{assets2_bluer_swallow}/20250616_134654.jpg": "",
        f"{assets2_bluer_swallow}/20250616_145049.jpg": "",
        f"{assets2_bluer_swallow}/20250618_102816~2_1.gif": "",
        f"{assets2_bluer_swallow}/20250618_122604.jpg": "",
        "../../../diagrams/bluer_swallow/cover.png": "../../../diagrams/bluer_swallow/cover.stl",
        f"{assets2_bluer_swallow}/20250629_123616.jpg": "",
        f"{assets2_bluer_swallow}/20250630_214923.jpg": "",
        f"{assets2_bluer_swallow}/20250701_2206342_1.gif": "",
        f"{assets2_bluer_swallow}/20250707_122000.jpg": "",
        f"{assets2_bluer_swallow}/20250707_182818.jpg": "",
        f"{assets2_bluer_swallow}/20250709_111955.jpg": "",
    }
)
