from bluer_objects.README.items import ImageItems

from bluer_ugv.README.consts import assets2_bluer_robin

items = ImageItems(
    {
        f"{assets2_bluer_robin}/20250712_114819.jpg": "",
        "../../../diagrams/bluer_robin/wiring.png": "../../../diagrams/bluer_robin/wiring.svg",
        f"{assets2_bluer_robin}/20250713_172325.jpg": "",
        f"{assets2_bluer_robin}/20250713_172413.jpg": "",
        f"{assets2_bluer_robin}/20250713_172442_1.gif": "",
        f"{assets2_bluer_robin}/20250723_095022.jpg": "",
        f"{assets2_bluer_robin}/20250723_095155~2_1.gif": "",
        f"{assets2_bluer_robin}/20250728_112123.jpg": "",
        f"{assets2_bluer_robin}/20250726_134024.jpg": "",
        f"{assets2_bluer_robin}/20250807_103534.jpg": "",
        f"{assets2_bluer_robin}/20250807_171354.jpg": "",
        f"{assets2_bluer_robin}/20250813_172023.jpg": "",
    }
)
