from bluer_ugv.help.swallow.dataset import help_functions as help_dataset
from bluer_ugv.help.swallow.env import help_functions as help_env
from bluer_ugv.help.swallow.select_target import help_select_target

help_functions = {
    "dataset": help_dataset,
    "env": help_env,
    "select_target": help_select_target,
}
