from bluer_objects.README.items import ImageItems

from bluer_ugv.README.consts import assets2_bluer_sparrow

items = ImageItems(
    {
        f"{assets2_bluer_sparrow}/20250722_174115-2.jpg": "",
        f"{assets2_bluer_sparrow}/20250818_191815.jpg": "",
    }
)
